@@ -5,7 +5,7 @@
 """Server for PB benchmark."""
 from __future__ import print_function
 
-from zope.interface import implements
+from zope.interface import implementer
 
 from twisted.spread import pb
 from twisted.internet import reactor
@@ -29,9 +29,8 @@ class PBBenchPerspective(pb.Avatar):
         return ['a', 1, 1, 1.0, [], ()]
 
 
+@implementer(IRealm)
 class SimpleRealm:
-    implements(IRealm)
-
     def requestAvatar(self, avatarId, mind, *interfaces):
         if pb.IPerspective in interfaces:
             p = PBBenchPerspective()
@@ -46,7 +45,7 @@ def main():
     from twisted.cred.checkers import InMemoryUsernamePasswordDatabaseDontUse
     portal = Portal(SimpleRealm())
     checker = InMemoryUsernamePasswordDatabaseDontUse()
-    checker.addUser("benchmark", "benchmark")
+    checker.addUser(b"benchmark", b"benchmark")
     portal.registerChecker(checker)
     reactor.listenTCP(8787, pb.PBServerFactory(portal))
     reactor.run()
