@@ -26,8 +26,8 @@ class BeginningPrinter(Protocol):
 
 agent = Agent(reactor)
 d = agent.request(
-    'GET',
-    'http://example.com/',
+    b'GET',
+    b'http://httpbin.com/anything/',
     Headers({'User-Agent': ['Twisted Web Client Example']}),
     None)
 
